==> vtk6-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkApplyColors.java <==
// java wrapper for vtkApplyColors object
//

package vtk;
import vtk.*;

public class vtkApplyColors extends vtkPassInputTypeAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPointLookupTable_2(vtkScalarsToColors id0);
  public void SetPointLookupTable(vtkScalarsToColors id0)
    { SetPointLookupTable_2(id0); }

  private native long GetPointLookupTable_3();
  public vtkScalarsToColors GetPointLookupTable() {
    long temp = GetPointLookupTable_3();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetUsePointLookupTable_4(boolean id0);
  public void SetUsePointLookupTable(boolean id0)
    { SetUsePointLookupTable_4(id0); }

  private native boolean GetUsePointLookupTable_5();
  public boolean GetUsePointLookupTable()
    { return GetUsePointLookupTable_5(); }

  private native void UsePointLookupTableOn_6();
  public void UsePointLookupTableOn()
    { UsePointLookupTableOn_6(); }

  private native void UsePointLookupTableOff_7();
  public void UsePointLookupTableOff()
    { UsePointLookupTableOff_7(); }

  private native void SetScalePointLookupTable_8(boolean id0);
  public void SetScalePointLookupTable(boolean id0)
    { SetScalePointLookupTable_8(id0); }

  private native boolean GetScalePointLookupTable_9();
  public boolean GetScalePointLookupTable()
    { return GetScalePointLookupTable_9(); }

  private native void ScalePointLookupTableOn_10();
  public void ScalePointLookupTableOn()
    { ScalePointLookupTableOn_10(); }

  private native void ScalePointLookupTableOff_11();
  public void ScalePointLookupTableOff()
    { ScalePointLookupTableOff_11(); }

  private native void SetDefaultPointColor_12(double id0,double id1,double id2);
  public void SetDefaultPointColor(double id0,double id1,double id2)
    { SetDefaultPointColor_12(id0,id1,id2); }

  private native void SetDefaultPointColor_13(double id0[]);
  public void SetDefaultPointColor(double id0[])
    { SetDefaultPointColor_13(id0); }

  private native double[] GetDefaultPointColor_14();
  public double[] GetDefaultPointColor()
    { return GetDefaultPointColor_14(); }

  private native void SetDefaultPointOpacity_15(double id0);
  public void SetDefaultPointOpacity(double id0)
    { SetDefaultPointOpacity_15(id0); }

  private native double GetDefaultPointOpacity_16();
  public double GetDefaultPointOpacity()
    { return GetDefaultPointOpacity_16(); }

  private native void SetSelectedPointColor_17(double id0,double id1,double id2);
  public void SetSelectedPointColor(double id0,double id1,double id2)
    { SetSelectedPointColor_17(id0,id1,id2); }

  private native void SetSelectedPointColor_18(double id0[]);
  public void SetSelectedPointColor(double id0[])
    { SetSelectedPointColor_18(id0); }

  private native double[] GetSelectedPointColor_19();
  public double[] GetSelectedPointColor()
    { return GetSelectedPointColor_19(); }

  private native void SetSelectedPointOpacity_20(double id0);
  public void SetSelectedPointOpacity(double id0)
    { SetSelectedPointOpacity_20(id0); }

  private native double GetSelectedPointOpacity_21();
  public double GetSelectedPointOpacity()
    { return GetSelectedPointOpacity_21(); }

  private native void SetPointColorOutputArrayName_22(String id0);
  public void SetPointColorOutputArrayName(String id0)
    { SetPointColorOutputArrayName_22(id0); }

  private native String GetPointColorOutputArrayName_23();
  public String GetPointColorOutputArrayName()
    { return GetPointColorOutputArrayName_23(); }

  private native void SetCellLookupTable_24(vtkScalarsToColors id0);
  public void SetCellLookupTable(vtkScalarsToColors id0)
    { SetCellLookupTable_24(id0); }

  private native long GetCellLookupTable_25();
  public vtkScalarsToColors GetCellLookupTable() {
    long temp = GetCellLookupTable_25();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetUseCellLookupTable_26(boolean id0);
  public void SetUseCellLookupTable(boolean id0)
    { SetUseCellLookupTable_26(id0); }

  private native boolean GetUseCellLookupTable_27();
  public boolean GetUseCellLookupTable()
    { return GetUseCellLookupTable_27(); }

  private native void UseCellLookupTableOn_28();
  public void UseCellLookupTableOn()
    { UseCellLookupTableOn_28(); }

  private native void UseCellLookupTableOff_29();
  public void UseCellLookupTableOff()
    { UseCellLookupTableOff_29(); }

  private native void SetScaleCellLookupTable_30(boolean id0);
  public void SetScaleCellLookupTable(boolean id0)
    { SetScaleCellLookupTable_30(id0); }

  private native boolean GetScaleCellLookupTable_31();
  public boolean GetScaleCellLookupTable()
    { return GetScaleCellLookupTable_31(); }

  private native void ScaleCellLookupTableOn_32();
  public void ScaleCellLookupTableOn()
    { ScaleCellLookupTableOn_32(); }

  private native void ScaleCellLookupTableOff_33();
  public void ScaleCellLookupTableOff()
    { ScaleCellLookupTableOff_33(); }

  private native void SetDefaultCellColor_34(double id0,double id1,double id2);
  public void SetDefaultCellColor(double id0,double id1,double id2)
    { SetDefaultCellColor_34(id0,id1,id2); }

  private native void SetDefaultCellColor_35(double id0[]);
  public void SetDefaultCellColor(double id0[])
    { SetDefaultCellColor_35(id0); }

  private native double[] GetDefaultCellColor_36();
  public double[] GetDefaultCellColor()
    { return GetDefaultCellColor_36(); }

  private native void SetDefaultCellOpacity_37(double id0);
  public void SetDefaultCellOpacity(double id0)
    { SetDefaultCellOpacity_37(id0); }

  private native double GetDefaultCellOpacity_38();
  public double GetDefaultCellOpacity()
    { return GetDefaultCellOpacity_38(); }

  private native void SetSelectedCellColor_39(double id0,double id1,double id2);
  public void SetSelectedCellColor(double id0,double id1,double id2)
    { SetSelectedCellColor_39(id0,id1,id2); }

  private native void SetSelectedCellColor_40(double id0[]);
  public void SetSelectedCellColor(double id0[])
    { SetSelectedCellColor_40(id0); }

  private native double[] GetSelectedCellColor_41();
  public double[] GetSelectedCellColor()
    { return GetSelectedCellColor_41(); }

  private native void SetSelectedCellOpacity_42(double id0);
  public void SetSelectedCellOpacity(double id0)
    { SetSelectedCellOpacity_42(id0); }

  private native double GetSelectedCellOpacity_43();
  public double GetSelectedCellOpacity()
    { return GetSelectedCellOpacity_43(); }

  private native void SetCellColorOutputArrayName_44(String id0);
  public void SetCellColorOutputArrayName(String id0)
    { SetCellColorOutputArrayName_44(id0); }

  private native String GetCellColorOutputArrayName_45();
  public String GetCellColorOutputArrayName()
    { return GetCellColorOutputArrayName_45(); }

  private native void SetUseCurrentAnnotationColor_46(boolean id0);
  public void SetUseCurrentAnnotationColor(boolean id0)
    { SetUseCurrentAnnotationColor_46(id0); }

  private native boolean GetUseCurrentAnnotationColor_47();
  public boolean GetUseCurrentAnnotationColor()
    { return GetUseCurrentAnnotationColor_47(); }

  private native void UseCurrentAnnotationColorOn_48();
  public void UseCurrentAnnotationColorOn()
    { UseCurrentAnnotationColorOn_48(); }

  private native void UseCurrentAnnotationColorOff_49();
  public void UseCurrentAnnotationColorOff()
    { UseCurrentAnnotationColorOff_49(); }

  private native int GetMTime_50();
  public int GetMTime()
    { return GetMTime_50(); }

  public vtkApplyColors() { super(); }

  public vtkApplyColors(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv6h.pkg.tar.xz: vtk/vtkApplyColors.java <==
// java wrapper for vtkApplyColors object
//

package vtk;
import vtk.*;

public class vtkApplyColors extends vtkPassInputTypeAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPointLookupTable_2(vtkScalarsToColors id0);
  public void SetPointLookupTable(vtkScalarsToColors id0)
    { SetPointLookupTable_2(id0); }

  private native long GetPointLookupTable_3();
  public vtkScalarsToColors GetPointLookupTable() {
    long temp = GetPointLookupTable_3();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetUsePointLookupTable_4(boolean id0);
  public void SetUsePointLookupTable(boolean id0)
    { SetUsePointLookupTable_4(id0); }

  private native boolean GetUsePointLookupTable_5();
  public boolean GetUsePointLookupTable()
    { return GetUsePointLookupTable_5(); }

  private native void UsePointLookupTableOn_6();
  public void UsePointLookupTableOn()
    { UsePointLookupTableOn_6(); }

  private native void UsePointLookupTableOff_7();
  public void UsePointLookupTableOff()
    { UsePointLookupTableOff_7(); }

  private native void SetScalePointLookupTable_8(boolean id0);
  public void SetScalePointLookupTable(boolean id0)
    { SetScalePointLookupTable_8(id0); }

  private native boolean GetScalePointLookupTable_9();
  public boolean GetScalePointLookupTable()
    { return GetScalePointLookupTable_9(); }

  private native void ScalePointLookupTableOn_10();
  public void ScalePointLookupTableOn()
    { ScalePointLookupTableOn_10(); }

  private native void ScalePointLookupTableOff_11();
  public void ScalePointLookupTableOff()
    { ScalePointLookupTableOff_11(); }

  private native void SetDefaultPointColor_12(double id0,double id1,double id2);
  public void SetDefaultPointColor(double id0,double id1,double id2)
    { SetDefaultPointColor_12(id0,id1,id2); }

  private native void SetDefaultPointColor_13(double id0[]);
  public void SetDefaultPointColor(double id0[])
    { SetDefaultPointColor_13(id0); }

  private native double[] GetDefaultPointColor_14();
  public double[] GetDefaultPointColor()
    { return GetDefaultPointColor_14(); }

  private native void SetDefaultPointOpacity_15(double id0);
  public void SetDefaultPointOpacity(double id0)
    { SetDefaultPointOpacity_15(id0); }

  private native double GetDefaultPointOpacity_16();
  public double GetDefaultPointOpacity()
    { return GetDefaultPointOpacity_16(); }

  private native void SetSelectedPointColor_17(double id0,double id1,double id2);
  public void SetSelectedPointColor(double id0,double id1,double id2)
    { SetSelectedPointColor_17(id0,id1,id2); }

  private native void SetSelectedPointColor_18(double id0[]);
  public void SetSelectedPointColor(double id0[])
    { SetSelectedPointColor_18(id0); }

  private native double[] GetSelectedPointColor_19();
  public double[] GetSelectedPointColor()
    { return GetSelectedPointColor_19(); }

  private native void SetSelectedPointOpacity_20(double id0);
  public void SetSelectedPointOpacity(double id0)
    { SetSelectedPointOpacity_20(id0); }

  private native double GetSelectedPointOpacity_21();
  public double GetSelectedPointOpacity()
    { return GetSelectedPointOpacity_21(); }

  private native void SetPointColorOutputArrayName_22(String id0);
  public void SetPointColorOutputArrayName(String id0)
    { SetPointColorOutputArrayName_22(id0); }

  private native String GetPointColorOutputArrayName_23();
  public String GetPointColorOutputArrayName()
    { return GetPointColorOutputArrayName_23(); }

  private native void SetCellLookupTable_24(vtkScalarsToColors id0);
  public void SetCellLookupTable(vtkScalarsToColors id0)
    { SetCellLookupTable_24(id0); }

  private native long GetCellLookupTable_25();
  public vtkScalarsToColors GetCellLookupTable() {
    long temp = GetCellLookupTable_25();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetUseCellLookupTable_26(boolean id0);
  public void SetUseCellLookupTable(boolean id0)
    { SetUseCellLookupTable_26(id0); }

  private native boolean GetUseCellLookupTable_27();
  public boolean GetUseCellLookupTable()
    { return GetUseCellLookupTable_27(); }

  private native void UseCellLookupTableOn_28();
  public void UseCellLookupTableOn()
    { UseCellLookupTableOn_28(); }

  private native void UseCellLookupTableOff_29();
  public void UseCellLookupTableOff()
    { UseCellLookupTableOff_29(); }

  private native void SetScaleCellLookupTable_30(boolean id0);
  public void SetScaleCellLookupTable(boolean id0)
    { SetScaleCellLookupTable_30(id0); }

  private native boolean GetScaleCellLookupTable_31();
  public boolean GetScaleCellLookupTable()
    { return GetScaleCellLookupTable_31(); }

  private native void ScaleCellLookupTableOn_32();
  public void ScaleCellLookupTableOn()
    { ScaleCellLookupTableOn_32(); }

  private native void ScaleCellLookupTableOff_33();
  public void ScaleCellLookupTableOff()
    { ScaleCellLookupTableOff_33(); }

  private native void SetDefaultCellColor_34(double id0,double id1,double id2);
  public void SetDefaultCellColor(double id0,double id1,double id2)
    { SetDefaultCellColor_34(id0,id1,id2); }

  private native void SetDefaultCellColor_35(double id0[]);
  public void SetDefaultCellColor(double id0[])
    { SetDefaultCellColor_35(id0); }

  private native double[] GetDefaultCellColor_36();
  public double[] GetDefaultCellColor()
    { return GetDefaultCellColor_36(); }

  private native void SetDefaultCellOpacity_37(double id0);
  public void SetDefaultCellOpacity(double id0)
    { SetDefaultCellOpacity_37(id0); }

  private native double GetDefaultCellOpacity_38();
  public double GetDefaultCellOpacity()
    { return GetDefaultCellOpacity_38(); }

  private native void SetSelectedCellColor_39(double id0,double id1,double id2);
  public void SetSelectedCellColor(double id0,double id1,double id2)
    { SetSelectedCellColor_39(id0,id1,id2); }

  private native void SetSelectedCellColor_40(double id0[]);
  public void SetSelectedCellColor(double id0[])
    { SetSelectedCellColor_40(id0); }

  private native double[] GetSelectedCellColor_41();
  public double[] GetSelectedCellColor()
    { return GetSelectedCellColor_41(); }

  private native void SetSelectedCellOpacity_42(double id0);
  public void SetSelectedCellOpacity(double id0)
    { SetSelectedCellOpacity_42(id0); }

  private native double GetSelectedCellOpacity_43();
  public double GetSelectedCellOpacity()
    { return GetSelectedCellOpacity_43(); }

  private native void SetCellColorOutputArrayName_44(String id0);
  public void SetCellColorOutputArrayName(String id0)
    { SetCellColorOutputArrayName_44(id0); }

  private native String GetCellColorOutputArrayName_45();
  public String GetCellColorOutputArrayName()
    { return GetCellColorOutputArrayName_45(); }

  private native void SetUseCurrentAnnotationColor_46(boolean id0);
  public void SetUseCurrentAnnotationColor(boolean id0)
    { SetUseCurrentAnnotationColor_46(id0); }

  private native boolean GetUseCurrentAnnotationColor_47();
  public boolean GetUseCurrentAnnotationColor()
    { return GetUseCurrentAnnotationColor_47(); }

  private native void UseCurrentAnnotationColorOn_48();
  public void UseCurrentAnnotationColorOn()
    { UseCurrentAnnotationColorOn_48(); }

  private native void UseCurrentAnnotationColorOff_49();
  public void UseCurrentAnnotationColorOff()
    { UseCurrentAnnotationColorOff_49(); }

  private native int GetMTime_50();
  public int GetMTime()
    { return GetMTime_50(); }

  public vtkApplyColors() { super(); }

  public vtkApplyColors(long id) { super(id); }
  public native long   VTKInit();

}
